@@ -10,6 +10,8 @@
 	2014.01.28 V00.05 Changed "hole punching" routine & bug fixed
 	2014.01.29 V00.06 Added PacketID check
 	2014.01.30 V00.07 Added ProductID & Vendor ID set routine
+	2014.01.31 V00.08 Bug fixed for login logic. 
+		(When callsign or password is wrong, dv_echo was looped.)
 */
 
 #include <stdio.h>
@@ -342,10 +344,10 @@ int main(int argc, const char **argv)
 	}
 
         hp = gethostbyname(TrustDomainName);
-        bcopy(hp->h_addr, &trustIP, hp->h_length);
+        memcpy (&trustIP, hp->h_addr_list[0], hp->h_length);
 
         hp = gethostbyname(TrustDbDomainName);
-        bcopy(hp->h_addr, &dbIP, hp->h_length);
+        memcpy (&dbIP, hp->h_addr_list[0], hp->h_length);
 
 	/* define mq attribute */
 	rf_mattr.mq_flags = O_NONBLOCK;
@@ -421,13 +423,18 @@ int main(int argc, const char **argv)
 
         //ポート番号入力のプロンプト
 	memset (buf, 0x20, 12);
-        while (memcmp (buf, "Port Number:", 12) != 0)
+	numrcv = recv (dstSocket, buf, 128, 0);
+        if (memcmp (buf, "Port Number:", 12) == 0)
 	{
-		numrcv = recv(dstSocket, buf, 128, 0);
        	 	buf[numrcv] = 0x00;
         	printf("%s\n",buf);
 	}
-
+	else
+	{
+		printf ("Invalid CallSign or Password\n");
+		CloseSocket();
+	}
+		
 	sprintf (buf, "%0d\0", client_port);
 	//ポート番号の送信
         send (dstSocket, buf, strlen(buf), 0);
@@ -435,7 +442,7 @@ int main(int argc, const char **argv)
         udpAddr.sin_family = PF_INET;
         udpAddr.sin_port = htons(client_port);
         udpAddr.sin_addr.s_addr = htonl(INADDR_ANY);
-        ret = bind(udpSocket, (struct sockaddr *)&udpAddr, sizeof(udpAddr));
+        bind(udpSocket, (struct sockaddr *)&udpAddr, sizeof(udpAddr));
 
         FD_ZERO(&Mask);
         FD_SET(dstSocket, &Mask);
