@@ -101,7 +101,7 @@ struct	repMsg
                         char            Rpt1Call[8];
                         char            YourCall[8];
                         char            MyCall[8];
-			char		trustname[16];
+			char		trust_name[16];
 			struct	in_addr	ip;
 			in_port_t	port;
 			unsigned char	PacketID[2];
